Module: Graphene

Defined in:
lib/graphene1/rect.rb,
lib/graphene1.rb,
lib/graphene1/size.rb,
lib/graphene1/vec2.rb,
lib/graphene1/point.rb,
lib/graphene1/loader.rb,
lib/graphene1/version.rb

Overview

Copyright (C) 2025 Ruby-GNOME Project Team

This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with this library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

Defined Under Namespace

Modules: Version Classes: Error, Loader, Point, Rect, Size, Vec2

Constant Summary collapse

LOG_DOMAIN =
"Graphene"